@@ -24,14 +24,14 @@ futureAssignInternal <- function(target, expr, envir=parent.frame(), substitute=
 } # futureAssignInternal()
 
 
-`%<=%` <- function(x, value) {
+`%<-%` <- `%<=%` <- function(x, value) {
   target <- substitute(x)
   expr <- substitute(value)
   envir <- parent.frame(1)
   futureAssignInternal(target, expr, envir=envir, substitute=FALSE)
 }
 
-`%=>%` <- function(value, x) {
+`%->%` <- `%=>%` <- function(value, x) {
   target <- substitute(x)
   expr <- substitute(value)
   envir <- parent.frame(1)
