@@ -1,9 +1,4 @@
-library("future")
-
-ovars <- ls()
-oopts <- options(warn=1L, mc.cores=2L, future.debug=TRUE)
-
-requestCore <- future:::requestCore
+source("incl/start.R")
 
 message("*** requestCore() ...")
 
@@ -12,12 +7,22 @@ message("*** requestCore() - exceptions ...")
 res <- try(requestCore(function() {}, workers=1L), silent=TRUE)
 stopifnot(inherits(res, "try-error"))
 
+res <- try(requestCore(function() {}, times=0L), silent=TRUE)
+stopifnot(inherits(res, "try-error"))
+
 message("*** requestCore() - exceptions ... DONE")
 
+
+message("*** requestCore() - timeout ...")
+
+plan(multicore, workers=2L)
+a %<-% { Sys.sleep(3); 1 }
+res <- try(requestCore(function() {}, workers=2L, times=1L, delta=0.1))
+stopifnot(inherits(res, "try-error"))
+stopifnot(a == 1)
+
+message("*** requestCore() - timeout ... DONE")
+
 message("*** requestCore() ... DONE")
 
-
-## Cleanup
-plan(eager)
-options(oopts)
-rm(list=setdiff(ls(), ovars))
+source("incl/end.R")
